clear all
cd "C:\Users\David\Dropbox\My Work Documents\Scandal\Passage of Time\replication materials"

*****************************************
*** CCAP REPLICATION ********************
*****************************************
/*RECODES, EXCLUSION OF UNUSED/DEANONYMIZING VARIABLES

use "ccap12_YALe_output.dta", clear
//keep respondents assigned to scandal study
keep if q390treat <7

** DEMOGRAPHICS
*Race
tab pp_race, gen(race)
gen r_white=race1
gen r_black=race2
gen r_hispanic=race3
gen r_otherrace=race4+race5+race6+race7
label var r_other "Other race / Skipped (1=yes)"
label var r_white "White (1=yes)"
label var r_black "Black (1=yes)"
label var r_hispanic "Hispanic (1=yes)"

*Gender
gen female=pp_gender-1
label var female "Female (1=yes)"

*Age
gen age=2012-pp_birthyr
gen age2=(age^2)/100
label var age "Age (in years)"
label var age2 "Age-squared/100"

*Family Income
gen income=pp_faminc
gen incomemis = (income>16)
qui sum income if (income<=16)
replace income=r(mean) if income>16
label var incomemis "Income Refused (1=yes)"
label var income "Income (1$=<$10k; 14$=>$150k; missing=mean)"

*Education
gen educ=pp_educ
label var educ "Education (1=No HS; 6=post-grad)"

*PID
recode pp_pid7 (1=-3) (2=-2) (3=-1) (4 8=0) (5=1) (6=2) (7=3) (*=.), gen(pid)
label var pid "Party ID (-3=Str. Rep.; 3=Str. Dem.)"

*Strength of PID
gen strpid=abs(pid)
label var strpid "Strength of Party Affiliation (0-3)"

*Ideology
recode pp_ideo5 (1=-2) (2=-1) (3 6 8=0) (4=1) (5=2), gen(ideology)
label var ideology "Ideology (-2=v. liberal; 2=v. conservative)"
*Str. Ideology
gen strideol = abs(ideology)
label var strideol "Strength of Ideology (0-2)"

*Interest in Politics
recode pp_newsint2 (1=4) (2=3) (3=2) (4=1) (*=.), gen(polinterest)
label var polinterest "Follow news? (1=hardly at all; 4=most of the time]"

**** GENERATE TREATMENT MEASURES
recode q390treat (3 4=1) (*=0),gen(trt_sex_old)
recode q390treat (5 6=1) (*=0),gen(trt_sex_recent)
label var trt_sex_old "Treatment: Sex Scandal - Old"
label var trt_sex_recent "Treatment: Sex Scandal - Recent"

***Outcomes
recode YAL390 (1=7) (2=6) (3=5) (4=4) (5=3) (6=2) (7=1), gen(vote_for)
replace vote_for =(vote_for-1)/6
gen job_rating=YAL391/100
gen feel_person=YAL392/100
label var vote_for  "Likely to Vote for Candidate (0-1)"
label var job_rating "Rating of Job as Representative (0-1)"
label var feel_person "Feel about as Person (0-1)"

*** Sample restriction
reg YAL390 YAL391 YAL392 
keep if e(sample)
alpha YAL390 YAL391 YAL392, i std gen(eval)
qui sum eval
replace eval=(eval-r(mean))/r(sd)
label var eval "Index of Candidate Evaluation (M=0; SD=1)"

reg vote_for job_rating feel_person trt_sex_old trt_sex_recent female r_black r_hispanic r_other age age2 educ income incomemis polinterest pid strpid ideology strideol, r
keep if e(sample)

keep eval vote_for job_rating feel_person trt_sex_old trt_sex_recent female r_black r_hispanic r_other age age2 educ income incomemis polinterest pid strpid ideology strideol

save "ccap12_replication.dta", replace
*/

use "ccap12_replication.dta", clear

outsum female r_black r_hispanic r_other age age2 educ income incomemis polinterest pid strpid ideology strideol using "tables/table_A1", replace bracket

foreach i in eval vote_for job_rating feel_person {
reg `i' trt_sex_old trt_sex_recent female r_black r_hispanic r_other age age2 educ income incomemis polinterest pid strpid ideology strideol, r
test trt_sex_old==trt_sex_recent 
if "`i'"=="eval"{
outreg using "tables/table_A2", se bracket replace 3aster rdec(3) adec(3) addstat("Test of Old-New (Sex Scandal)",r(p))
}
if "`i'"=="vote_for"{
outreg using "tables/table_A3", se bracket replace 3aster rdec(3) adec(3) addstat("Test of Old-New (Sex Scandal)",r(p))
}
if "`i'"=="job_rating" | "`i'"=="feel_person" {
outreg using "tables/table_A3", se bracket append 3aster rdec(3) adec(3) addstat("Test of Old-New (Sex Scandal)",r(p))
}
}

***************************************************
**** MECHANICAL TURK ******************************
***************************************************
/*RECODES, EXCLUSION OF UNUSED/DEANONYMIZING VARIABLES
clear all
insheet using mturk_study.csv, comma name
//keep only cases assigned to scandal experiment
keep if experiment=="Scandal"
//use "mturk_data.dta", clear
drop if country!="United States"
rename whichstatedoyoulivein state
drop if state=="Palau" | state=="Federated States of Micronesia"

** DEMOGRAPHICS
*Party ID
rename generallyspeakingdoyouusuallythi pid_stem
rename wouldyoucallyourselfastrongdemoc pid_dstr
rename wouldyoucallyourselfastrongrepub pid_rstr
rename doyouthinkofyourselfasclosertoth pid_lean
egen pid=rmean(pid_dstr pid_rstr pid_lean)
label var pid "Respondent Party ID (-1=S Dem; 1=S Rep)"
gen strpid=abs(pid)
label var strpid "Strength of Party Affiliation (0-3)"

rename whatistheyearofyourbirth yob
gen age=2012-yob
label var age "Age (in years)"
gen age2=(age*age)/100
label var age2 "Age-squared/100"

rename whatisthehighestlevelofeducation educ
label var educ "Education (1=No HS; 6=post-grad)"
rename whatwasyourtotalfamilyincomein20 income
label var income "Income (1=<$10k; 14=$150k+; 15=refused)"
gen incomemis=(income==15)
label var incomemis "Income Refused (1=yes)"

foreach i in white black hispanic asian nativeamerican mixed other{
rename `i'whatracialorethnic r_`i'
 replace r_`i'=0 if r_`i'==.
 replace r_`i'=1 if r_`i'!=0
 label var r_`i' "`i' = 1"
}
replace r_other=r_asian+r_nativeam+r_mixed+r_other
replace r_other=1 if r_other>1
replace r_white=0 if (r_black==1)| (r_hispanic==1)|(r_other==1)
replace r_black=0 if (r_hispanic==1)|(r_other==1)
replace r_hispanic=0 if (r_other==1)
replace r_other=1 if (r_white!=1)&(r_black!=1)&(r_hispanic!=1)

label var r_other "Other race / Skipped (1=yes)"
label var r_white "White (1=yes)"
label var r_black "Black (1=yes)"
label var r_hispanic "Hispanic (1=yes)"
drop r_asian r_nativeam r_mixed 

rename whatisyourgender female
label var female "Female (1=yes)"

recode howinterestedareyouinpoliticsand (1=3) (2=2) (3=1) (*=.), gen(polinterest)
label var polinterest "Interest in politics (1=not at all; 3=very interested)"

rename wehearalotoftalkthesedaysaboutli ideology
replace  ideology = ideology-4
label var ideology "Ideology (-3=v. liberal; 3=v. conservative)"
gen strideol = abs(ideology)
label var strideol "Strength of Ideology (0-3)"

*** TREATMENTS
tab  scandal, mis gen(trt_scandal)
drop trt_scandal1
rename trt_scandal2 trt_sex_recent
rename trt_scandal3 trt_fin_recent
rename trt_scandal4 trt_sex_old
rename trt_scandal5 trt_fin_old
label var trt_sex_old "Treatment: Sex Scandal - Old"
label var trt_sex_recent "Treatment: Sex Scandal - Recent"
label var trt_fin_old "Treatment: Tax Scandal - Old"
label var trt_fin_recent "Treatment: Tax Scandal - Recent"



** OUTCOMES
gen vote_for=(ifyoulivedinrepresentativejonesd-7)/-6
gen job_rating=(basedonwhatyouknowaboutrepresent-1)/6
gen feel_person=(howdoyoufeelaboutrepresentativej-1)/6
label var vote_for "Likely to Vote For (0-1)"
label var job_rating "Job Rating (0-1)"
label var feel_person "Feel about as Person (0-1)"

drop if age<18
reg vote_for job_rating feel_person female r_black r_hispanic r_other age educ income incomemis polinterest ideology pid
keep if e(sample)

alpha vote_for job_rating feel_person, i std gen(eval)
qui sum eval
replace eval=(eval-r(mean))/r(sd)
label var eval "Index of Candidate Evaluation (M = 0; SD = 1)"

keep eval vote_for job_rating feel_person trt_sex_old trt_sex_recent trt_fin_old trt_fin_recent female r_black r_hispanic r_other age age2 educ income incomemis polinterest strpid ideology strideol  pid
save "mturk_replication.dta", replace
*/

use "mturk_replication.dta", clear

outsum female r_black r_hispanic r_other age age2 educ income incomemis polinterest pid strpid ideology strideol using "tables/table_A1", append bracket


foreach i in eval vote_for job_rating feel_person {
reg `i' trt_sex_old trt_sex_recent trt_fin_old trt_fin_recent female r_black r_hispanic r_other age age2 educ income incomemis polinterest pid strpid ideology strideol, r
test trt_fin_old==trt_fin_recent 
local fin_p=r(p)
test trt_sex_old==trt_sex_recent 
if "`i'"=="eval"{
outreg using "tables/table_A2", se bracket append 3aster rdec(3) adec(3) addstat("Test of Old-New (Sex Scandal)",`r(p)',"Test of Old-New (Tax Scandal)",`fin_p')
}
else{
outreg using "tables/table_A3", se bracket append 3aster rdec(3) adec(3) addstat("Test of Old-New (Sex Scandal)",`r(p)',"Test of Old-New (Tax Scandal)",`fin_p')
}
}

